@@ -48,6 +48,7 @@ class Bot:
         self.aliases = {}
         self.chat_filter = []
         self.ignore_filter = []
+        self.all_commands = []
         self._skip_check = lambda x, y: x == y
         timeout = aiohttp.ClientTimeout(total=100, connect=10)
         user_agent = kwargs.get('user_agent', None)
@@ -154,7 +155,7 @@ class Bot:
             if aliases is not None:
                 for al in aliases:
                     self.add_command(al, command)
-
+            self.all_commands.append(command)
         return decorator
 
     def listener(self, ignore_filter=False):
@@ -335,6 +336,7 @@ class Bot:
                     command.has_arts = v.has_arts
                 self.add_command(v.__command__, command)
                 self.actions_from_cog.update({command: cls})
+                self.all_commands.append(command)
             elif '__listener__' in dir(v):
                 self.add_listener(v.__listener__, v)
                 self.actions_from_cog.update({v: cls})
